#!/usr/bin/env python3
'''
This example script loads a CSV file and filters the columns. The results are written to a new CSV file.

Created on 2013.02.19.
@author: Gergo Horanyi

'''

import sys
import csv
import os.path
import argparse

parser = argparse.ArgumentParser()
parser.add_argument("ipt", help="ipt file path", type=str, action="store")
parser.add_argument("output", help="output file path", type=str, action="store")
parser.add_argument("filter", nargs="+", help="columns to keep", type=str)
args = parser.parse_args()

if os.path.exists(args.output):
    print("ERROR: Output file already exists.")
    sys.exit(1)
if os.path.exists(args.input) == False:
    print("ERROR: Input file does not exists.")
    sys.exit(2)

ipt = open(args.input)
output = open(args.output, 'w')
reader = csv.reader(ipt) # open a CSV reader for ipt
writer = csv.writer(output) # open a CSV writer for output
rownum = 0
columnsToKeep = []
for line in reader:
    if rownum == 0: # Header row
        colnum = 0
        newHeader = []
        for column in line:
            if column in args.filter:
                columnsToKeep.append(colnum)
                newHeader.append(column)
            colnum = colnum + 1
        writer.writerow(newHeader) # Writing out the new header
    else: # Not the header
        row = []
        for i in columnsToKeep:
            row.append(line[i])
        writer.writerow(row) # Writing out filtered data row
    rownum = rownum + 1

# Closing the opened files
ipt.close()
output.close()