#!/usr/bin/env python3
'''
This example script loads a CSV file and filters the columns. The results are written to a new CSV file.

Created on 2014.01.13.
@author: Tamás Nádudvari

'''

import sys
import csv
import os.path
import argparse

parser = argparse.ArgumentParser()
parser.add_argument("input", help="ipt file path", type=str, action="store")
parser.add_argument("output", help="output file path", type=str, action="store")
parser.add_argument("filter", nargs="+", help="columns to keep", type=str)
args = parser.parse_args()

if os.path.exists(args.output):
    print("ERROR: Output file already exists.")
    sys.exit(1)
if os.path.exists(args.input) == False:
    print("ERROR: Input file does not exists.")
    sys.exit(2)

with open(args.input) as input,  open(args.output, 'w')  as output:
    reader = csv.DictReader(input) # open a CSV DictReader for input.
    writer = csv.DictWriter(output, args.filter) # open a CSV DictWriter for output, set the header names.
    writer.writeheader() # write out header line.
    for line in reader:
        new_line = {} # dict for the new output.
        for key in line.keys():
            # copying only the filtered rows in to the new output. 
            if key in args.filter:
                new_line[key] = line[key]
        writer.writerow(new_line)